@@ -269,9 +269,12 @@ def publish_package():
             Datapackage.package_id==package_data['id']
         ).order_by(Datapackage.created.desc()).first()
         if datapackage:
-            datapackage.errors = validation.to_dict()
+            new_datapackage = Datapackage()
+            new_datapackage.package_id = datapackage.package_id
+            new_datapackage.data = datapackage.data
+            new_datapackage.errors = validation.to_dict()
+            model.Session.add(new_datapackage)
             model.Session.commit()
-    default_backend.validate_package(package_data)
     response = make_response()
     response.content_type = 'application/json'
     response.data = json.dumps(data_response)
@@ -375,7 +378,7 @@ def datapackage_validation_show(package_id):
     }
     package = get_action('package_show')(context, data)
     datapackage_list = model.Session.query(Datapackage).filter(
-        Datapackage.package_id==package_id
+        Datapackage.package_id==package['id']
     ).order_by(Datapackage.created.desc())
     return toolkit.render(
         'datapackage_creator/validation_read.html',
