@@ -1,6 +1,7 @@
 import datetime as dt
 import uuid
 import logging
+import json
 
 from sqlalchemy import Column, Unicode, DateTime
 from sqlalchemy.ext.declarative import declarative_base
@@ -28,6 +29,9 @@ class Datapackage(Base):
     data = Column(JSON)
     errors = Column(JSON)
 
+    def errors_json(self):
+        return json.dumps(self.errors)
+
 
 class DatapackageResource(Base):
     __tablename__ = u'datapackage_resource'
